# Molecule Collection

[![CI](https://github.com/ansible/molecule/actions/workflows/tox.yml/badge.svg?event=push)](https://github.com/ansible/molecule/actions/workflows/tox.yml) [![Codecov](https://img.shields.io/codecov/c/github/ansible/molecule)](https://codecov.io/gh/ansible/molecule)

`community.molecule` collection aims to help molecule users to write and maintain their
molecule tests.

This collection contains:

- filters that can be used inside molecule testing playbooks
- examples on how to use molecule for testing content with different type of
  infrastructure.

## External requirements

Filters and modules provided do require molecule python package to be installed
and they are not supposed to be used outside molecule testing playbooks.

## Release notes

See the [changelog](https://github.com/ansible/molecule/tree/main/community.molecule/CHANGELOG.rst).

## More information

<!-- List out where the user can find additional information, such as working group meeting times, slack/IRC channels, or documentation for the product this collection automates. At a minimum, link to: -->

- [Ansible Developers](https://docs.ansible.com/developers.html)
- [Ansible User guide](https://docs.ansible.com/users.html)
- [Ansible Developer guide](https://docs.ansible.com/ansible/latest/dev_guide/index.html)
- [Ansible Collections Checklist](https://docs.ansible.com/ansible/devel/community/collection_contributors/collection_requirements.html)
- [Ansible Community code of conduct](https://docs.ansible.com/ansible/latest/community/code_of_conduct.html)
- [The Bullhorn (the Ansible Contributor newsletter)](https://forum.ansible.com/c/news/bullhorn/17)

## Licensing

[MIT](https://github.com/ansible-collections/community.molecule/blob/main/LICENSE)
